==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Help/About/ts/About_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>About</name>
    <message>
        <location filename="../About.js" line="+62"/>
        <source>About %1</source>
        <translation>%1について</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Revision:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+19"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Portions of this software © 2008-2016 The Qt Company Ltd.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>プラグイン</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>No information available</source>
        <translation>利用可能な情報がありません</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>プラグイン:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>記述:</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <location line="-115"/>
        <location line="+108"/>
        <source>Version:</source>
        <translation>バージョン:</translation>
    </message>
    <message>
        <location line="-95"/>
        <location line="+99"/>
        <source>Qt Version:</source>
        <translation>Qtバージョン:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>License:</source>
        <translation>ライセンス:</translation>
    </message>
    <message>
        <location line="-109"/>
        <location line="+118"/>
        <location line="+12"/>
        <source>Internet:</source>
        <translation>インターネット:</translation>
    </message>
    <message>
        <location line="-128"/>
        <source>Build Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Architecture:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Compiler:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 is free (open source) software.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <source>No plugins found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+93"/>
        <source>Active</source>
        <translation>アクティブ</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>機能停止（リスタート）</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>体験版:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>ファイル:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>エラー:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Script Add-Ons</source>
        <translation>スクリプトアドオン</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Credits</source>
        <translation>クレジット</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>&amp;A ソフトウェアについて...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Translations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Templates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>About QCAD</source>
        <translation type="obsolete">QCADについて</translation>
    </message>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>ソフトウェアについて</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+134"/>
        <source>Plugins</source>
        <translation>プラグイン</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>スクリプト</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>システム</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Credits</source>
        <translation>クレジット</translation>
    </message>
    <message>
        <source>About Plugins</source>
        <translation type="obsolete">プラグインについて</translation>
    </message>
    <message>
        <source>About Script Add-Ons</source>
        <translation type="obsolete">スクリプトアドオンについて</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Help/About/ts/About_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>About</name>
    <message>
        <location filename="../About.js" line="+63"/>
        <source>About %1</source>
        <translation>%1について</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Revision:</source>
        <translation>リビジョン:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation>これは、誰でも&lt;a href=&apos;%1&apos;&gt;参加&lt;/a&gt;できることを意味します!</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2018 The Qt Company Ltd.</source>
        <translation type="obsolete">このソフトウェアの一部にQtを使用しています。© 2008-2017 The Qt Company Ltd. {2008-2018 ?}</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>プログラムは現状のまま提供され、設計、商品性、および特定の目的への適合性を含む、いかなる保証もありません。</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>プラグイン</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>No information available</source>
        <translation>利用可能な情報がありません</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>プラグイン:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>記述:</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <location line="-128"/>
        <location line="+121"/>
        <source>Version:</source>
        <translation>バージョン:</translation>
    </message>
    <message>
        <location line="-111"/>
        <location line="+115"/>
        <source>Qt Version:</source>
        <translation>Qtバージョン:</translation>
    </message>
    <message>
        <location line="-85"/>
        <source>Portions of this software © %1 The Qt Company Ltd.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+89"/>
        <source>License:</source>
        <translation>ライセンス:</translation>
    </message>
    <message>
        <location line="-125"/>
        <location line="+134"/>
        <location line="+11"/>
        <source>Internet:</source>
        <translation>インターネット:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Build Date:</source>
        <translation>ビルド日付:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Architecture:</source>
        <translation>アーキテクチャー:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Compiler:</source>
        <translation>コンパイラ:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License Key:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation>%1 は、 コンピュータ支援設計computer-aided design (CAD)のアプリケーションです。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation>%1 はQCADに基づき、自由で（オープンソースな）ソフトウェアです。</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 is free (open source) software.</source>
        <translation>%1は自由で（オープンソースな）ソフトウェアです。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation>プラグインとスクリプト拡張機能は個別のライセンスが適用されます（&apos;プラグイン&apos;タブ参照）</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation>すべてのブランドまたは製品名は、それぞれの所有者の商標または登録商標です。</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2017 The Qt Company Ltd.</source>
        <translation type="vanished">このソフトウェアの一部にQtを使用しています。© 2008-2017 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>No plugins found.</source>
        <translation>プラグインがありません</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>Active</source>
        <translation>アクティブ</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>機能停止（リスタート）</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>体験版:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>ファイル:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>エラー:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Script Add-Ons</source>
        <translation>スクリプトアドオン</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation>スクリプト拡張機能がありません。</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Credits</source>
        <translation>クレジット</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>&amp;A ソフトウェアについて...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation>プログラミング</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Translations</source>
        <translation>翻訳</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Templates</source>
        <translation>テンプレート</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation>アイコン</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation>テスト、フィードバック及び小規模調整</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>About QCAD</source>
        <translation type="obsolete">QCADについて</translation>
    </message>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>ソフトウェアについて</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+134"/>
        <source>Plugins</source>
        <translation>プラグイン</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>スクリプト</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>システム</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Credits</source>
        <translation>クレジット</translation>
    </message>
    <message>
        <source>About Plugins</source>
        <translation type="obsolete">プラグインについて</translation>
    </message>
    <message>
        <source>About Script Add-Ons</source>
        <translation type="obsolete">スクリプトアドオンについて</translation>
    </message>
</context>
</TS>
